%define pkg_version 3.7.2
%define api_version 0.4.1

Name: brltty
Version: %{pkg_version}
Release: 4%{?dist}
License: GPL
Group: System Environment/Daemons
URL: http://mielke.cc/brltty/
Source: http://mielke.cc/brltty/releases/%{name}-%{version}.tar.gz
Patch0: brltty-3.7.2-linux-compiler-h.patch
Patch1: brltty-3.7.2-vt-buildfix.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-InstallRoot
Summary: Braille display driver for Linux/Unix.
Requires(post): coreutils
BuildRequires: byacc, glibc-kernheaders
Requires: brlapi = %{api_version}-%{release}

%description
BRLTTY is a background process (daemon) which provides
access to the Linux/Unix console (when in text mode)
for a blind person using a refreshable braille display.
It drives the braille display,
and provides complete screen review functionality.
Some speech capability has also been incorporated.

%package -n brlapi
Version: %{api_version}
Group: Applications/System
License: LGPL
Summary: Appliation Programming Interface for BRLTTY.
%description -n brlapi
This package provides the run-time support for the Application
Programming Interface to BRLTTY.

Install this package if you have an application which directly accesses
a refreshable braille display.

%package -n brlapi-devel
Version: %{api_version}
Group: Development/System
License: LGPL
Requires: brlapi = %{api_version}-%{release}

Summary: Headers, static archive, and documentation for BrlAPI.
%description -n brlapi-devel
This package provides the header files, static archive, shared object
linker reference, and reference documentation for BrlAPI (the
Application Programming Interface to BRLTTY).  It enables the
implementation of applications which take direct advantage of a
refreshable braille display in order to present information in ways
which are more appropriate for blind users and/or to provide user
interfaces which are more specifically atuned to their needs.

Install this package if you are developing or maintaining an application
which directly accesses a refreshable braille display.

%prep
%setup
%patch0 -p1 -b .linux-compiler-h
%patch1 -p1

%build
%configure --without-curses \
  --with-data-directory='%{_sysconfdir}/brltty' \
  --with-install-root="${RPM_BUILD_ROOT}" --with-braille-driver=-tt \
  --no-create
# prevent bogus rpath in %{_libdir}/brltty/libbrlttybba.so (CVE-2008-3279, #457942)
sed -i '/@braille_libraries_/ s/-Wl,-rpath[^ ]*//' config.status
./config.status
make

for file in $(find . \( -path ./doc -o -path ./Documents \) -prune -o \( -name 'README*' -o -name '*.txt' -o -name '*.html' -o -name '*.sgml' -o -name \*.patch -o \( -path "./Bootdisks/*" -type f -perm +ugo=x \) \) -print)
do
   mkdir -p "doc/${file%/*}"
   cp -rp "${file}" "doc/${file}"
done

%install
make install INSTALL_PROGRAM='$(INSTALL_SCRIPT)'
mv "$RPM_BUILD_ROOT%{_sysconfdir}/brltty/brltty-pm.conf" \
	doc/BrailleDrivers/Papenmeier/
install -d -m 755 "${RPM_BUILD_ROOT}%{_sysconfdir}" "$RPM_BUILD_ROOT%{_mandir}/man5"
install -m 644 Documents/brltty.conf "${RPM_BUILD_ROOT}%{_sysconfdir}"
echo ".so man1/brltty.1" > $RPM_BUILD_ROOT%{_mandir}/man5/brltty.conf.5

rm -f ${RPM_BUILD_ROOT}/usr/bin/xbrlapi # whatever this is, we exclude it for now

%clean
rm -rf $RPM_BUILD_ROOT

%post
devices="/dev/vcsa /dev/vcsa0 /dev/vcc/a"
install=true
for device in ${devices}
do
   if [ -c "${device}" ]
   then
      install=false
      break
   fi
done
if $install
then
   device="$(set -- ${devices} && echo "${1}")"
   mkdir -p "${device%/*}"
   mknod -m o= "${device}" c 7 128
   chmod 660 "${device}"
   chown root.tty "${device}"
fi
exit 0

%files
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/brltty.conf
%{_bindir}/brltty
%{_bindir}/brltty-*
%{_libdir}/brltty
%{_sysconfdir}/brltty
%doc COPYING
%doc Documents/ChangeLog Documents/TODO
%doc Documents/Manual{.txt,.sgml,-HTML/}
%doc Bootdisks/rhmkboot Bootdisks/rhmkroot
%doc doc/*
%doc %{_mandir}/man[15]/*

%files -n brlapi
%defattr(-,root,root)
%{_libdir}/libbrlapi.so.*
%doc Documents/BrlAPI{.txt,.sgml,-HTML/}
%doc Documents/README.Gnopernicus

%files -n brlapi-devel
%defattr(-,root,root)
%{_libdir}/libbrlapi.a
%{_libdir}/libbrlapi.so
%{_includedir}/brltty
%doc %{_mandir}/man3/*
%doc Documents/BrlAPIref-HTML

%changelog
* Wed Oct 28 2009 Stepan Kasal <skasal@redhat.com> - 3.7.2-4
- use rpm macros more consistently
- add manual page for brltty.conf
- add more documentation
- install the default brltty-pm.conf to docdir only
- Resolves: #530554
- silence the postinstall scriptlet
- Resolves: #529163

* Tue Oct 20 2009 Stepan Kasal <skasal@redhat.com> - 3.7.2-3
- escape rpm macros in the rpm change log
- remove bogus rpath from libbrlttybba.so (CVE-2008-3279, #457942)
- add dependencies to bind the subpackages from one build together

* Tue Oct 20 2009 Stepan Kasal <skasal@redhat.com> - 3.7.2-2
- fix building with newer kernel-headers (#456247)
- do not strip debug info during install (#500545)
- Resolves: rhbz #456247 #500545

* Wed Jul 12 2006 Petr Rockai <prockai@redhat.com> - 3.7.2-1
- upgrade to latest upstream version
- split off brlapi and brlapi-devel packages

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 3.2-12.1
- rebuild

* Sun Jul 02 2006 Florian La Roche <laroche@redhat.com>
- for the post script require coreutils

* Mon Jun 05 2006 Jesse Keating <jkeating@redhat.com> - 3.2-11
- Added byacc BuildRequires, removed prereq, coreutils is always there

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 3.2-10.2.1
- bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 3.2-10.2
- rebuilt for new gcc4.1 snapshot and glibc changes

* Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt

* Wed Mar 16 2005 Bill Nottingham <notting@redhat.com> 3.2-10
- rebuild

* Fri Nov 26 2004 Florian La Roche <laroche@redhat.com>
- add a %%clean into .spec

* Thu Oct 14 2004 Adrian Havill <havill@redhat.com> 3.2-5
- chmod a-x for conf file (#116244)

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Tue Mar 02 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Tue Sep 30 2003 Florian La Roche <Florian.LaRoche@redhat.de>
- prereq coreutils for mknod/chown/chmod

* Mon Jul 07 2003 Adrian Havill <havill@redhat.com> 3.2-2
- changed spec "Copyright" to "License"
- use %%configure macro, %%{_libdir} for non-ia32 archs
- removed unnecessary set and unset, assumed/default spec headers
- fixed unpackaged man page, duplicate /bin and /lib entries
- use plain install vs scripts for non-i386 buildsys
